PrecreateOrder class

Constructors

PrecreateOrder({required String qrCode, required String outTradeNo, required String totalAmount, String? tradeNo})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
outTradeNo String
final
qrCode String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalAmount String
final
tradeNo String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited